@@ -9,7 +9,7 @@ Test::Strict - Check syntax, presence of use strict; and test coverage
 C<Test::Strict> lets you check the syntax, presence of C<use strict;>
 and presence C<use warnings;>
 in your perl code.
-It report its results in standard C<Test::Simple> fashion:
+It report its results in standard L<Test::Simple> fashion:
 
   use Test::Strict tests => 3;
   syntax_ok( 'bin/myscript.pl' );
@@ -44,7 +44,7 @@ or
 =head1 DESCRIPTION
 
 The most basic test one can write is "does it compile ?".
-This module tests if the code compiles and play nice with C<Test::Simple> modules.
+This module tests if the code compiles and play nice with L<Test::Simple> modules.
 
 Another good practice this module can test is to "use strict;" in all perl files.
 
@@ -59,7 +59,7 @@ controlled by C<$Test::Strict::UNTAINT_PATTERN>.
 
 =cut
 
-use strict;
+use strict; use warnings;
 use 5.004;
 use Test::Builder;
 use File::Spec;
@@ -68,7 +68,7 @@ use File::Find;
 use Config;
 
 our $COVER;
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 our $PERL    = $^X || 'perl';
 our $COVERAGE_THRESHOLD = 50; # 50%
 our $UNTAINT_PATTERN    = qr|^(.*)$|;
@@ -240,7 +240,7 @@ sub _strict_ok {
 Experimental. Returning a list of modules and pragmata that enable strict.
 To modify this list, change C<@Test::Strict::MODULES_ENABLING_STRICT>.
 
-List taken from https://metacpan.org/pod/Module::CPANTS::Kwalitee::Uses v95
+List taken from L<Module::CPANTS::Kwalitee::Uses> v95
 
 =cut
 
@@ -257,6 +257,7 @@ our @MODULES_ENABLING_STRICT = qw(
   Mojo::Base
   Moo
   Moo::Role
+  MooX
   Moose
   Moose::Exporter
   Moose::Role
@@ -281,7 +282,7 @@ sub modules_enabling_strict { return @MODULES_ENABLING_STRICT }
 Experimental. Returning a list of modules and pragmata that enable warnings
 To modify this list, change C<@Test::Strict::MODULES_ENABLING_WARNINGS>.
 
-List taken from https://metacpan.org/pod/Module::CPANTS::Kwalitee::Uses v95
+List taken from L<Module::CPANTS::Kwalitee::Uses> v95
 
 =cut
 
@@ -298,6 +299,7 @@ our @MODULES_ENABLING_WARNINGS = qw(
   Mojo::Base
   Moo
   Moo::Role
+  MooX
   Moose
   Moose::Exporter
   Moose::Role
@@ -425,7 +427,7 @@ The threshold can be modified through C<$Test::Strict::COVERAGE_THRESHOLD>.
 You may want to select which files are selected for code
 coverage through C<$Test::Strict::DEVEL_COVER_OPTIONS>,
 see L<Devel::Cover> for the list of available options.
-The default is '+ignore,"/Test/Strict\b"'. 
+The default is '+ignore,"/Test/Strict\b"'.
 
 The path to C<cover> utility can be modified through C<$Test::Strict::COVER>.
 
@@ -557,11 +559,11 @@ this may lead to some side effects.
 
 =head1 SEE ALSO
 
-L<Test::More>, L<Test::Pod>. L<Test::Distribution>, L<Test:NoWarnings>
+L<Test::More>, L<Test::Pod>. L<Test::Distribution>, L<Test::NoWarnings>
 
 =head1 REPOSITORY
 
-L<https://github.com/szabgab/Test-Strict>
+L<https://github.com/Manwar/Test-Strict>
 
 =head1 AUTHOR
 
@@ -571,6 +573,8 @@ Pierre Denis, C<< <pdenis@gmail.com> >>.
 
 L<Gabor Szabo|http://szabgab.com/>
 
+Mohammad S Anwar (MANWAR), C<< <mohammad.anwar at yahoo.com> >>
+
 =head1 COPYRIGHT
 
 Copyright 2005, 2010 Pierre Denis, All Rights Reserved.
